@@ -1,5 +1,7 @@
+from origamibot.core.teletypes.command_scope import BotCommandScope
 import shlex
 import logging
+from tests import bot, token
 
 from typing import List, Optional, Union, IO, Callable
 from collections import deque
@@ -84,7 +86,9 @@ from .api_request import (
     edit_message_reply_markup,
     stop_poll,
     delete_message,
-    send_media_group)
+    send_media_group,
+    delete_my_commands
+    )
 
 from ..listener import Listener
 
@@ -105,7 +109,7 @@ except ImportError:
     pass
 
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger('origamibot')
 
 
 class OrigamiBot:
@@ -325,7 +329,9 @@ class OrigamiBot:
                      disable_web_page_preview: Optional[bool] = None,
                      disable_notification: Optional[bool] = None,
                      reply_to_message_id: Optional[int] = None,
-                     reply_markup: Optional[ReplyMarkup] = None) -> Message:
+                     reply_markup: Optional[ReplyMarkup] = None,
+                     protect_content: Optional[bool] = None
+                     ) -> Message:
         """Use this method to send text messages.
 
         On success, the sent Message is returned.
@@ -337,7 +343,8 @@ class OrigamiBot:
                             disable_web_page_preview,
                             disable_notification,
                             reply_to_message_id,
-                            reply_markup)
+                            reply_markup,
+                            protect_content)
 
     def reply_to(self, 
                  msg: Message,
@@ -345,7 +352,9 @@ class OrigamiBot:
                  parse_mode: Optional[str] = None,
                  disable_web_page_preview: Optional[bool] = None,
                  disable_notification: Optional[bool] = None,
-                 reply_markup: Optional[ReplyMarkup] = None) -> Message:
+                 reply_markup: Optional[ReplyMarkup] = None,
+                 protect_content: Optional[bool] = None
+                 ) -> Message:
         mid = msg.message_id
         cid = msg.chat.id
         return self.send_message(
@@ -355,24 +364,27 @@ class OrigamiBot:
             disable_web_page_preview=disable_web_page_preview,
             disable_notification=disable_notification,
             reply_to_message_id=mid,
-            reply_markup=reply_markup
+            reply_markup=reply_markup,
+            protect_content=protect_content
         )
 
     def forward_message(self,
                         chat_id: Union[int, str],
                         from_chat_id: Union[int, str],
                         message_id: int,
-                        disable_notification: Optional[bool] = None
+                        disable_notification: Optional[bool] = None,
+                        protect_content: Optional[bool] = None
                         ) -> Message:
         """Use this method to forward messages of any kind.
 
         On success, the sent Message is returned."""
         return forward_message(
-            self.token,
-            chat_id,
-            from_chat_id,
-            message_id,
-            disable_notification
+            token=self.token,
+            chat_id=chat_id,
+            from_chat_id=from_chat_id,
+            message_id=message_id,
+            disable_notification=disable_notification,
+            protect_content=protect_content
         )
 
     def send_photo(self,
@@ -382,20 +394,23 @@ class OrigamiBot:
                    parse_mode: Optional[str] = None,
                    disable_notification: Optional[bool] = None,
                    reply_to_message_id: Optional[int] = None,
-                   reply_markup: Optional[ReplyMarkup] = None) -> Message:
+                   reply_markup: Optional[ReplyMarkup] = None,
+                   protect_content: Optional[bool] = None
+                   ) -> Message:
         """Use this method to send photos.
 
         On success, the sent Message is returned.
         """
         return send_photo(
-            self.token,
-            chat_id,
-            photo,
-            caption,
-            parse_mode,
-            disable_notification,
-            reply_to_message_id,
-            reply_markup
+            token=self.token,
+            chat_id=chat_id,
+            photo=photo,
+            caption=caption,
+            parse_mode=parse_mode,
+            disable_notification=disable_notification,
+            reply_to_message_id=reply_to_message_id,
+            reply_markup=reply_markup,
+            protect_content=protect_content
         )
 
     def send_audio(self,
@@ -409,7 +424,8 @@ class OrigamiBot:
                    thumb: Optional[Union[str, IO]] = None,
                    disable_notification: Optional[bool] = None,
                    reply_to_message_id: Optional[int] = None,
-                   reply_markup: Optional[ReplyMarkup] = None
+                   reply_markup: Optional[ReplyMarkup] = None,
+                   protect_content: Optional[bool] = None
                    ) -> Message:
         """Use this method to send audio files.
 
@@ -417,18 +433,19 @@ class OrigamiBot:
         On success, the sent Message is returned.
         """
         return send_audio(
-            self.token,
-            chat_id,
-            audio,
-            caption,
-            parse_mode,
-            duration,
-            performer,
-            title,
-            thumb,
-            disable_notification,
-            reply_to_message_id,
-            reply_markup
+            token=self.token,
+            chat_id=chat_id,
+            audio=audio,
+            caption=caption,
+            parse_mode=parse_mode,
+            duration=duration,
+            performer=performer,
+            title=title,
+            thumb=thumb,
+            disable_notification=disable_notification,
+            reply_to_message_id=reply_to_message_id,
+            reply_markup=reply_markup,
+            protect_content=protect_content
         )
 
     def send_document(self,
@@ -439,22 +456,24 @@ class OrigamiBot:
                       parse_mode: Optional[str] = None,
                       disable_notification: Optional[bool] = None,
                       reply_to_message_id: Optional[int] = None,
-                      reply_markup: Optional[ReplyMarkup] = None
+                      reply_markup: Optional[ReplyMarkup] = None,
+                      protect_content: Optional[bool] = None
                       ) -> Message:
         """Use this method to send general files.
 
         On success, the sent Message is returned.
         """
         return send_document(
-            self.token,
-            chat_id,
-            document,
-            thumb,
-            caption,
-            parse_mode,
-            disable_notification,
-            reply_to_message_id,
-            reply_markup
+            token=self.token,
+            chat_id=chat_id,
+            document=document,
+            thumb=thumb,
+            caption=caption,
+            parse_mode=parse_mode,
+            disable_notification=disable_notification,
+            reply_to_message_id=reply_to_message_id,
+            reply_markup=reply_markup,
+            protect_content=protect_content
         )
 
     def send_video(self,
@@ -469,7 +488,8 @@ class OrigamiBot:
                    supports_streaming: Optional[bool] = None,
                    disable_notification: Optional[bool] = None,
                    reply_to_message_id: Optional[int] = None,
-                   reply_markup: Optional[ReplyMarkup] = None
+                   reply_markup: Optional[ReplyMarkup] = None,
+                   protect_content: Optional[bool] = None
                    ) -> Message:
         """Use this method to send video files.
 
@@ -478,19 +498,20 @@ class OrigamiBot:
         On success, the sent Message is returned.
         """
         return send_video(
-            self.token,
-            chat_id,
-            video,
-            duration,
-            width,
-            height,
-            thumb,
-            caption,
-            parse_mode,
-            supports_streaming,
-            disable_notification,
-            reply_to_message_id,
-            reply_markup
+            token=self.token,
+            chat_id=chat_id,
+            video=video,
+            duration=duration,
+            width=width,
+            height=height,
+            thumb=thumb,
+            caption=caption,
+            parse_mode=parse_mode,
+            supports_streaming=supports_streaming,
+            disable_notification=disable_notification,
+            reply_to_message_id=reply_to_message_id,
+            reply_markup=reply_markup,
+            protect_content=protect_content
         )
 
     def send_animation(self,
@@ -504,25 +525,27 @@ class OrigamiBot:
                        parse_mode: Optional[str] = None,
                        disable_notification: Optional[bool] = None,
                        reply_to_message_id: Optional[int] = None,
-                       reply_markup: Optional[ReplyMarkup] = None
+                       reply_markup: Optional[ReplyMarkup] = None,
+                       protect_content: Optional[bool] = None
                        ) -> Message:
         """Use this method to send animation files (GIF or video without sound).
 
         On success, the sent Message is returned.
         """
         return send_animation(
-            self.token,
-            chat_id,
-            animation,
-            duration,
-            width,
-            height,
-            thumb,
-            caption,
-            parse_mode,
-            disable_notification,
-            reply_to_message_id,
-            reply_markup
+            token=self.token,
+            chat_id=chat_id,
+            animation=animation,
+            duration=duration,
+            width=width,
+            height=height,
+            thumb=thumb,
+            caption=caption,
+            parse_mode=parse_mode,
+            disable_notification=disable_notification,
+            reply_to_message_id=reply_to_message_id,
+            reply_markup=reply_markup,
+            protect_content=protect_content
         )
 
     def send_voice(self,
@@ -533,7 +556,8 @@ class OrigamiBot:
                    duration: Optional[int] = None,
                    disable_notification: Optional[bool] = None,
                    reply_to_message_id: Optional[int] = None,
-                   reply_markup: Optional[ReplyMarkup] = None
+                   reply_markup: Optional[ReplyMarkup] = None,
+                   protect_content: Optional[bool] = None
                    ) -> Message:
         """Use this method to send audio files to display the file as a voice message.
 
@@ -541,15 +565,16 @@ class OrigamiBot:
         On success, the sent Message is returned.
         """
         return send_voice(
-            self.token,
-            chat_id,
-            voice,
-            caption,
-            parse_mode,
-            duration,
-            disable_notification,
-            reply_to_message_id,
-            reply_markup
+            token=self.token,
+            chat_id=chat_id,
+            voice=voice,
+            caption=caption,
+            parse_mode=parse_mode,
+            duration=duration,
+            disable_notification=disable_notification,
+            reply_to_message_id=reply_to_message_id,
+            reply_markup=reply_markup,
+            protect_content=protect_content
         )
 
     def send_video_note(self,
@@ -560,21 +585,23 @@ class OrigamiBot:
                         thumb: Optional[Union[str, IO]] = None,
                         disable_notification: Optional[bool] = None,
                         reply_to_message_id: Optional[int] = None,
-                        reply_markup: Optional[ReplyMarkup] = None
+                        reply_markup: Optional[ReplyMarkup] = None,
+                        protect_content: Optional[bool] = None
                         ) -> Message:
         """Use this method to send rounded square mp4 videos of up to 1 minute long.
 
         On success, the sent Message is returned."""
         return send_video_note(
-            self.token,
-            chat_id,
-            video_note,
-            duration,
-            length,
-            thumb,
-            disable_notification,
-            reply_to_message_id,
-            reply_markup
+            token=self.token,
+            chat_id=chat_id,
+            video_note=video_note,
+            duration=duration,
+            length=length,
+            thumb=thumb,
+            disable_notification=disable_notification,
+            reply_to_message_id=reply_to_message_id,
+            reply_markup=reply_markup,
+            protect_content=protect_content
         )
 
     def send_location(self,
@@ -584,21 +611,23 @@ class OrigamiBot:
                       live_period: Optional[int] = None,
                       disable_notification: Optional[bool] = None,
                       reply_to_message_id: Optional[int] = None,
-                      reply_markup: Optional[ReplyMarkup] = None
+                      reply_markup: Optional[ReplyMarkup] = None,
+                      protect_content: Optional[bool] = None
                       ) -> Message:
         """Use this method to send point on the map.
 
         On success, the sent Message is returned.
         """
         return send_location(
-            self.token,
-            chat_id,
-            latitude,
-            longitude,
-            live_period,
-            disable_notification,
-            reply_to_message_id,
-            reply_markup
+            token=self.token,
+            chat_id=chat_id,
+            latitude=latitude,
+            longitude=longitude,
+            live_period=live_period,
+            disable_notification=disable_notification,
+            reply_to_message_id=reply_to_message_id,
+            reply_markup=reply_markup,
+            protect_content=protect_content
         )
 
     def edit_message_live_location(self,
@@ -663,24 +692,26 @@ class OrigamiBot:
                    foursquare_type: Optional[str] = None,
                    disable_notification: Optional[bool] = None,
                    reply_to_message_id: Optional[int] = None,
-                   reply_markup: Optional[ReplyMarkup] = None
+                   reply_markup: Optional[ReplyMarkup] = None,
+                   protect_content: Optional[bool] = None
                    ) -> Message:
         """Use this method to send information about a venue.
 
         On success, the sent Message is returned.
         """
         return send_venue(
-            self.token,
-            chat_id,
-            latitude,
-            longitude,
-            title,
-            address,
-            foursquare_id,
-            foursquare_type,
-            disable_notification,
-            reply_to_message_id,
-            reply_markup
+            token=self.token,
+            chat_id=chat_id,
+            latitude=latitude,
+            longitude=longitude,
+            title=title,
+            address=address,
+            foursquare_id=foursquare_id,
+            foursquare_type=foursquare_type,
+            disable_notification=disable_notification,
+            reply_to_message_id=reply_to_message_id,
+            reply_markup=reply_markup,
+            protect_content=protect_content
         )
 
     def send_contact(self,
@@ -691,22 +722,24 @@ class OrigamiBot:
                      vcard: Optional[str] = None,
                      disable_notification: Optional[bool] = None,
                      reply_to_message_id: Optional[int] = None,
-                     reply_markup: Optional[ReplyMarkup] = None
+                     reply_markup: Optional[ReplyMarkup] = None,
+                     protect_content: Optional[bool] = None
                      ) -> Message:
         """Use this method to send phone contacts.
 
         On success, the sent Message is returned.
         """
         return send_contact(
-            self.token,
-            chat_id,
-            phone_number,
-            first_name,
-            last_name,
-            vcard,
-            disable_notification,
-            reply_to_message_id,
-            reply_markup
+            token=self.token,
+            chat_id=chat_id,
+            phone_number=phone_number,
+            first_name=first_name,
+            last_name=last_name,
+            vcard=vcard,
+            disable_notification=disable_notification,
+            reply_to_message_id=reply_to_message_id,
+            reply_markup=reply_markup,
+            protect_content=protect_content
         )
 
     def send_poll(self,
@@ -724,29 +757,31 @@ class OrigamiBot:
                   is_closed: Optional[bool] = None,
                   disable_notification: Optional[bool] = None,
                   reply_to_message_id: Optional[int] = None,
-                  reply_markup: Optional[ReplyMarkup] = None
+                  reply_markup: Optional[ReplyMarkup] = None,
+                  protect_content: Optional[bool] = None
                   ) -> Message:
         """Use this method to send a native poll.
 
         On success, the sent Message is returned.
         """
         return send_poll(
-            self.token,
-            chat_id,
-            question,
-            options,
-            is_anonymous,
-            type,
-            allows_multiple_answers,
-            correct_option_id,
-            explanation,
-            explanation_parse_mode,
-            open_period,
-            close_date,
-            is_closed,
-            disable_notification,
-            reply_to_message_id,
-            reply_markup
+            token=self.token,
+            chat_id=chat_id,
+            question=question,
+            options=options,
+            is_anonymous=is_anonymous,
+            type=type,
+            allows_multiple_answers=allows_multiple_answers,
+            correct_option_id=correct_option_id,
+            explanation=explanation,
+            explanation_parse_mode=explanation_parse_mode,
+            open_period=open_period,
+            close_date=close_date,
+            is_closed=is_closed,
+            disable_notification=disable_notification,
+            reply_to_message_id=reply_to_message_id,
+            reply_markup=reply_markup,
+            protect_content=protect_content
         )
 
     def send_dice(self,
@@ -754,19 +789,21 @@ class OrigamiBot:
                   emoji: Optional[str] = None,
                   disable_notification: Optional[bool] = None,
                   reply_to_message_id: Optional[int] = None,
-                  reply_markup: Optional[ReplyMarkup] = None
+                  reply_markup: Optional[ReplyMarkup] = None,
+                  protect_content: Optional[bool] = None
                   ) -> Message:
         """Use this method to send an animated emoji that will display a random value.
 
         On success, the sent Message is returned.
         """
         return send_dice(
-            self.token,
-            chat_id,
-            emoji,
-            disable_notification,
-            reply_to_message_id,
-            reply_markup
+            token=self.token,
+            chat_id=chat_id,
+            emoji=emoji,
+            disable_notification=disable_notification,
+            reply_to_message_id=reply_to_message_id,
+            reply_markup=reply_markup,
+            protect_content=protect_content
         )
 
     def send_chat_action(self,
@@ -790,17 +827,19 @@ class OrigamiBot:
                          chat_id: Union[int, str],
                          media: List[InputMedia],
                          disable_notification: Optional[bool] = None,
-                         reply_to_message_id: Optional[bool] = None
+                         reply_to_message_id: Optional[bool] = None,
+                         protect_content: Optional[bool] = None
                          ) -> Message:
         """Use this method to send a group of photos or videos as an album.
         On success, an array of the sent Messages is returned
         """
         return send_media_group(
-            self.token,
-            chat_id,
-            media,
-            disable_notification,
-            reply_to_message_id
+            token=self.token,
+            chat_id=chat_id,
+            media=media,
+            disable_notification=disable_notification,
+            reply_to_message_id=reply_to_message_id,
+            protect_content=protect_content
         )
 
     def get_user_profile_photos(self,
@@ -1149,7 +1188,9 @@ class OrigamiBot:
         )
 
     def set_my_commands(self,
-                        commands: List[BotCommand]
+                        commands: List[BotCommand],
+                        scope: Optional[BotCommandScope] = None,
+                        language_code: Optional[str] = None
                         ) -> bool:
         """Use this method to change the list of the bot's commands.
 
@@ -1160,12 +1201,24 @@ class OrigamiBot:
             commands
         )
 
-    def get_my_commands(self) -> List[BotCommand]:
+    def get_my_commands(self,
+                        language_code: Optional[str] = None
+                        ) -> List[BotCommand]:
         """Use this method to get the current list of the bot's commands.
 
         Returns Array of BotCommand on success.
         """
         return get_my_commands(self.token)
+    
+    def delete_my_commands(self,
+                           scope: Optional[BotCommandScope] = None,
+                           language_code: Optional[str] = None
+                           ) -> bool:
+        return delete_my_commands(
+            token=self.token,
+            scope=scope,
+            language_code=language_code
+        )
 
     def answer_inline_query(self,
                             inline_query_id: str,
@@ -1457,11 +1510,14 @@ class OrigamiBot:
                     continue
 
             # Parse arguments for each command
-            if commands:
-                _, nxt_c, _ = commands[0]
-                args = [message] + shlex.split(text[end:nxt_c])
-            else:
-                args = [message] + shlex.split(text[end:])
+            try:
+                if commands:
+                    _, nxt_c, _ = commands[0]
+                    args = [message] + shlex.split(text[end:nxt_c])
+                else:
+                    args = [message] + shlex.split(text[end:])
+            except ValueError:
+                args = [message, text[end:]]
 
             found = self.command_container.find_command(command)
             for method in found:
